@@ -6,10 +6,13 @@
 from UltiSnips import _vim
 from UltiSnips.text_objects._base import NoneditableTextObject
 
+
 class VimLCode(NoneditableTextObject):
+
     """See module docstring."""
+
     def __init__(self, parent, token):
-        self._code = token.code.replace("\\`", "`").strip()
+        self._code = token.code.replace('\\`', '`').strip()
 
         NoneditableTextObject.__init__(self, parent, token)
 
